@@ -11,8 +11,7 @@ import argparse
 from .processor import Processor
 from .log import setup_logging
 
-__all__ = "main"
-
+import os
 
 __version__ = "1.0"
 
@@ -125,24 +124,28 @@ def main():
     """
     Commandline entrypoint
     """
-    defaults = {"format": "", "overwrite": False, "on_change": True, "verbose": False, "force": False, "zipy": False, "sort": False, "comments": False, "timestamp": False, "wrap": False, "input": "", "output": ""}
-    args = vars(parse_arguments(defaults))
-    settings = {**defaults, **args}
-    verbose = settings.get("verbose", False)
-    if verbose:
-        logger.info(f"web-minifier version {__version__} started")
-
-    processor = Processor(settings)
-    res, msg = processor.sanity_checks()
-    if not res:
-        logger.error("Sanity check failed: {msg}, quiting...")
-        sys.exit(1)
-    if verbose:
-        logger.info("Sanity check passed!")
-    if not processor.process_files():
-        logger.error("Processing failed, quiting...")
-        sys.exit(1)
-    if verbose:
-        logger.info("Processing completed successfully!")
-    # logger.info(f'\n {"-" * 80} \n Files Processed: {list_of_files}.')
-    # logger.info(f'''Number of Files Processed: {len(list_of_files) if isinstance(list_of_files, tuple) else 1}.''')
+    try:
+        defaults = {"format": "", "overwrite": False, "on_change": True, "verbose": False, "force": False, "zipy": False, "sort": False, "comments": False, "timestamp": False, "wrap": False, "input": "", "output": ""}
+        args = vars(parse_arguments(defaults))
+        settings = {**defaults, **args}
+        verbose = settings.get("verbose", False)
+        if verbose:
+            logger.info(f"web-minifier version {__version__} started")
+    
+        processor = Processor(settings)
+        res, msg = processor.sanity_checks()
+        if not res:
+            logger.error("Sanity check failed: {msg}, quiting...")
+            sys.exit(1)
+        if verbose:
+            logger.info("Sanity check passed!")
+        if not processor.process_files():
+            logger.error("Processing failed, quiting...")
+            sys.exit(1)
+        if verbose:
+            logger.info("Processing completed successfully!")
+        # logger.info(f'\n {"-" * 80} \n Files Processed: {list_of_files}.')
+        # logger.info(f'''Number of Files Processed: {len(list_of_files) if isinstance(list_of_files, tuple) else 1}.''')
+    except Exception as e:
+        logger.error(f"Failed in {os.getcwd()} with {e}")
+        raise e
