@@ -32,15 +32,7 @@ class Processor:
         self.force: bool = settings.get("force", False)
 
         # fmt off
-        self.processor_map = {
-            "sass": (sass_minify, False),
-            "css": (css_minify, False),
-            "html": (html_minify, False),
-            "svg": (svg_minify, False),
-            "js": (js_minify, False),
-            "png": (png_minify, True),
-            "jpeg": (jpeg_minify, True)
-        }
+        self.processor_map = {"sass": (sass_minify, False), "css": (css_minify, False), "html": (html_minify, False), "svg": (svg_minify, False), "js": (js_minify, False), "json": (js_minify, False), "png": (png_minify, True), "jpeg": (jpeg_minify, True)}
         # fmt on
 
         self.valid_extensions = [f".{ext}" for ext in self.processor_map.keys()]
@@ -71,29 +63,38 @@ class Processor:
             return False, False, False, "No input path specified"
         if not output_path:
             return False, False, False, "No output path specified"
-        input_mtime = now.timestamp()
+        input_mtime = os.path.getmtime(input_path)
+        output_mtime = None
         if os.path.isfile(output_path):
             if not self.overwrite:
                 return False, False, False, "Trying to overwrite without overwrite enabled"
             if self.on_change:
-                input_mtime = os.path.getmtime(input_path)
                 output_mtime = os.path.getmtime(output_path)
                 if not self.force and (input_mtime == output_mtime):
                     return True, False, True, "File not changed, skipping"
-                elif not self.force and (output_mtime > input_mtime):
-                    return True, False, True, "Destination file newer than input, skipping"
+                elif not self.force and (output_mtime >= input_mtime):
+                    return True, False, True, f"Destination file newer than input, skipping ({output_mtime} >= {input_mtime})"
         else:
             output_dir = os.path.dirname(output_path)
             if not os.path.isdir(output_dir):
                 os.makedirs(name=output_dir, exist_ok=True)
             if not os.path.isdir(output_dir):
                 return False, False, False, "Output directory did not exist or could not be created"
-        extension = determine_file_extension(input_path)
+        extension, raw_extension = determine_file_extension(input_path)
+        vip_file = False
         if not extension:
-            return False, False, False, f"Unknown extension '{extension}' for input file"
-        processor, is_binary = self.processor_map.get(extension, None)
-        if not processor:
-            return False, False, False, "Could not find processor for input file"
+            # Skip well known files with unsupported file extensions
+            base_name = os.path.basename(input_path)
+            if base_name in ["sitemap.xml", "favicon.ico", "robots.txt"]:
+                vip_file = True
+            else:
+                return False, False, False, f"Unknown extension '{raw_extension}' for input file"
+        processor = None
+        is_binary = True
+        if not vip_file:
+            processor, is_binary = self.processor_map.get(extension, None)
+            if not processor:
+                return False, False, False, "Could not find processor for input file"
         original_content = None
         try:
             with open(input_path, "rb") if is_binary else open(input_path, "r", encoding="utf-8") as file:
@@ -104,7 +105,8 @@ class Processor:
             logger.warning(f"Input file '{input_path}' was empty")
         processed_content = None
         was_copied = False
-        if extension in ["js", "css", "html", "svg", "png", "jpeg"] and self.settings.get(f"disable_{extension}", False):
+        do_copy = vip_file or (extension in ["js", "css", "html", "svg", "png", "jpeg"] and self.settings.get(f"disable_{extension}", False))
+        if do_copy:
             # Perform copy
             # logger.info(f"SUPPOSED TO COPY: {input_path} ({extension})")
             processed_content = original_content
@@ -115,7 +117,7 @@ class Processor:
             # TODO: make message mechanism for processor
         # logger.info(f"Content of file {input_path} was of type {type(original_content)} while processed {type(processed_content)}")
         if None == processed_content:
-            logger.warning(f"Processed file for '{input_path}' was empty")
+            logger.warning(f"Processed file '{input_path}' was empty")
         try:
             with open(output_path, "wb") if is_binary else open(output_path, "w", encoding="utf-8") as file:
                 written = file.write(processed_content)
@@ -150,7 +152,8 @@ class Processor:
             if skipped:
                 skipped_count += 1
             if message:
-                messages[message] = 1 + messages.get(message, 0)
+                all = messages.get(message, [])
+                messages[message] = [*all, f"{input_path}"]
 
             single_end_time = datetime.datetime.now()
             single_interval = single_end_time - single_start_time
@@ -165,8 +168,15 @@ class Processor:
         logger.info(f"Processing of {len(list)} files with {success_count} successful, {copied_count} copied and {skipped_count} skipped, generated {len(messages)} message(s) and took {human_delta(interval)} total")
         if messages:
             logger.warning(f"Messages encountered were:")
-            for message, count in messages.items():
-                logger.warning(f"{count} x {message}")
+            for message, all in messages.items():
+                logger.warning(f"{len(all)} x {message}")
+                show_count = 5
+                count = len(all)
+                for index in range(min(show_count, count)):
+                    logger.warning(f"    {all[index]}")
+                if show_count < count:
+                    logger.warning(f"    ... and {count-show_count} more")
+                logger.warning("")
         return True
 
     def _process_existing_dir_to_existing_dir(self):
